KeyCmpContext

Struct KeyCmpContext 

pub struct KeyCmpContext<KF> { /* private fields */ }
Used to easily wrap multiple values with the same key function.

Implementations

Source

impl<KF> KeyCmpContext<KF>

pub fn new<T, K>(key_func: KF) -> KeyCmpContext<KF>
where KF: Fn(&T) -> K,

Creates new key context which lets you easily wrap values with the same key function (same context).

pub fn wrap<T>(&self, value: T) -> CmpByKey<'_, KF, T>

This is how you wrap values in the same context context.

use cmp_wrap::strict::KeyCmpContext;

let by_length = KeyCmpContext::new(|v: &Vec<_>| v.len());

let long_vec = by_length.wrap(vec![1,2,3,4]);
let short_vec = by_length.wrap(vec![1,2]);

assert!(long_vec > short_vec, "The vec {:?} is longer then {:?}", long_vec, short_vec);